# == Class: rubies::chruby
#
# Installs chruby.
#
# === Parameters
#
# [*release*]
#   (Required) The release of chruby to install.
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#

class rubies::chruby (
  $release
) {

  $repo = 'https://github.com/postmodern/chruby'
  $source = "${repo}/archive/v${release}.tar.gz"
  $tarball = "/opt/chruby-${release}.tar.gz"
  $dest_dir = "/opt/chruby-${release}"

  exec { 'chruby-download':
    path    => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command => "wget ${source} -O ${tarball}",
    timeout => '900',
    creates => $tarball
  }

  exec { 'chruby-unpack':
    path    => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command => "tar -xzC /opt -f ${tarball}",
    creates => $dest_dir,
    require => Exec['chruby-download'],
    notify  => Exec['chruby-install']
  }

  exec { 'chruby-install':
    path        => [ '/bin/', '/sbin/' , '/usr/bin/', '/usr/sbin/' ],
    command     => "make install -C ${dest_dir}",
    refreshonly => true,
    require     => Exec['chruby-unpack']
  }

}
