# == Class: rubies
#
# Installs and configures self-packaged versions of Ruby.
#
# === Parameters
#
# [*versions*]
#   (Optional) An array of Ruby package names to be installed (defaults to
#   an empty array).
#
# [*default*]
#   (Optional) The default version of ruby to activate in shells (defaults
#   to system).
#
# [*chruby_release*]
#   (Optional) The version of chruby to be instaled (defaults to 0.3.9).
#
# === Authors
#
# David McNicol <david@mcnicks.org>
#

class rubies (
  $versions = [],
  $default = 'system',
  $chruby_release = '0.3.9'
) {

  # Deploy the required Ruby versions.

  rubies::deploy { $versions: }

  # Install chruby.

  class { 'rubies::chruby':
    release => $chruby_release
  }

  contain 'rubies::chruby'

  # Add chruby globally.

  file { '/etc/profile.d/chruby.sh':
    ensure  => 'present',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => template('rubies/chruby.sh.erb')
  }

}
